summaryrefslogtreecommitdiff
path: root/firmware/include/vboot_api.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/include/vboot_api.h')
-rw-r--r--firmware/include/vboot_api.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/firmware/include/vboot_api.h b/firmware/include/vboot_api.h
index c5b382ac..38c5cbda 100644
--- a/firmware/include/vboot_api.h
+++ b/firmware/include/vboot_api.h
@@ -118,8 +118,9 @@ enum VbErrorPredefined_t {
VBERROR_EC_REBOOT_TO_SWITCH_RW = 0x1001A,
/* Developer has requested a BIOS shell */
VBERROR_BIOS_SHELL_REQUESTED = 0x10020,
- /* Need VGA and don't have it, or vice-versa */
- VBERROR_VGA_OPROM_MISMATCH = 0x10021,
+ /* Need initialized display and don't have it, or vice-versa.
+ Deprecated; should use VBERROR_REBOOT_REQUIRED instead. */
+ VBERROR_DEPRECATED_DISPLAY_INIT_MISMATCH = 0x10021,
/* Need EC to reboot to read-only code */
VBERROR_EC_REBOOT_TO_RO_REQUIRED = 0x10022,
/* Invalid region read parameters */